import React from "react";
import { useParams } from "react-router-dom";
import { Light as SyntaxHighlighter } from "react-syntax-highlighter";
import xml from "react-syntax-highlighter/dist/esm/languages/hljs/xml";
import { dracula } from "react-syntax-highlighter/dist/esm/styles/hljs";
import xmlFormat from "xml-formatter";
import { VMApi, VMInfo } from "../api/VMApi";
import { AsyncWidget } from "../widgets/AsyncWidget";
import { VirtWebRouteContainer } from "../widgets/VirtWebRouteContainer";
import { IconButton } from "@mui/material";
import { RouterLink } from "../widgets/RouterLink";
import ArrowBackIcon from "@mui/icons-material/ArrowBack";

SyntaxHighlighter.registerLanguage("xml", xml);

export function VMXMLRoute(): React.ReactElement {
  const { uuid } = useParams();

  const [vm, setVM] = React.useState<VMInfo | undefined>();
  const [src, setSrc] = React.useState<string | undefined>();

  const load = async () => {
    setVM(await VMApi.GetSingle(uuid!));
    setSrc(await VMApi.GetSingleXML(uuid!));
  };

  return (
    <AsyncWidget
      loadKey={uuid}
      load={load}
      errMsg="Failed to load VM information!"
      build={() => <XMLRouteInner vm={vm!} src={src!} />}
    />
  );
}

function XMLRouteInner(p: { vm: VMInfo; src: string }): React.ReactElement {
  const xml = xmlFormat(p.src);

  return (
    <VirtWebRouteContainer
      label={`XML definition of ${p.vm.name}`}
      actions={
        <RouterLink to={p.vm.ViewURL}>
          <IconButton>
            <ArrowBackIcon />
          </IconButton>
        </RouterLink>
      }
    >
      <SyntaxHighlighter
        language="xml"
        style={dracula}
        customStyle={{ fontSize: "120%" }}
      >
        {xml}
      </SyntaxHighlighter>
    </VirtWebRouteContainer>
  );
}
